.. _rockverse_docs_tutorials:

#########
Tutorials
#########

.. grid:: 1
    :gutter: 4

    .. grid-item-card:: Digital Rock Petrophysics

        - :doc:`Introduction to Voxel Images <tutorials/digitalrock/voxel_image>`
        - Visualizing Orthogonal Slices
            - :doc:`Importing sample raw data - Bentheimer sandstone<tutorials/digitalrock/sample_data/import_bentheimer_sandstone>`
            - :doc:`Exploring the orthogonal viewer <tutorials/digitalrock/orthogonal_viewer>`
        - Monte Carlo Dual Energy CT processing
            - :doc:`Importing sample raw data - Carbonate dual energy <tutorials/digitalrock/sample_data/import_C04B21_dualenergy>`


        - Importing sample raw data
            - :doc:`Importing sample raw data - Belgian Fieldstone <tutorials/digitalrock/sample_data/import_belgian_fieldstone>`



    .. grid-item-card:: Well logging

        <Comming soon!>

    .. grid-item-card:: Petrogeophysics

        <Comming soon!>


.. toctree::
    :hidden:
    :maxdepth: 1

    tutorials/digitalrock.rst
